Require Visual C++ 2013 to build Mozc for Windows

To reduce the number of actively maintained build configurations, we will discontinue the support of Visual C++ 2010 and 2012.

With this CL, the required Windows Installer version is also bumped from 3.0 to 4.5 because merge modules of Visual C++ 2013 requires Windows Installer 4.5 or later.  This should be OK because Mozc supports Windows Vista SP2 and later, and Windows Vista SP2 was shipped with Windows Installer 4.5.

Basically no user visible change is intended.

BUG=none
TEST=unittest

git-svn-id: https://mozc.googlecode.com/svn/trunk@509 a6090854-d499-a067-5803-1114d4e51264
diff --git a/src/gyp/common.gypi b/src/gyp/common.gypi
index 683a056..1ade5c9 100644
--- a/src/gyp/common.gypi
+++ b/src/gyp/common.gypi
@@ -126,18 +126,6 @@
     'conditions': [
       ['OS=="win"', {
         'conditions': [
-          ['MSVS_VERSION=="2010"', {
-            'compiler_target': 'msvs',
-            'compiler_target_version_int': 1600,  # Visual C++ 2010 or higher
-            'compiler_host': 'msvs',
-            'compiler_host_version_int': 1600,  # Visual C++ 2010 or higher
-          }],
-          ['MSVS_VERSION=="2012"', {
-            'compiler_target': 'msvs',
-            'compiler_target_version_int': 1700,  # Visual C++ 2012 or higher
-            'compiler_host': 'msvs',
-            'compiler_host_version_int': 1700,  # Visual C++ 2012 or higher
-          }],
           ['MSVS_VERSION=="2013"', {
             'compiler_target': 'msvs',
             'compiler_target_version_int': 1800,  # Visual C++ 2013 or higher
diff --git a/src/mozc_version_template.txt b/src/mozc_version_template.txt
index 5a1fbb2..9d93f99 100644
--- a/src/mozc_version_template.txt
+++ b/src/mozc_version_template.txt
@@ -1,6 +1,6 @@
 MAJOR=2
 MINOR=16
-BUILD=2035
+BUILD=2036
 REVISION=102
 # NACL_DICTIONARY_VERSION is the target version of the system dictionary to be
 # downloaded by NaCl Mozc.
diff --git a/src/testing/testing.gyp b/src/testing/testing.gyp
index 3aa0544..77b6000 100644
--- a/src/testing/testing.gyp
+++ b/src/testing/testing.gyp
@@ -62,11 +62,6 @@
           'GTEST_HAS_TR1_TUPLE=1',
         ],
         'conditions': [
-          ['_toolset=="target" and compiler_target=="msvs" and compiler_target_version_int==1700', {
-            'gtest_defines': [
-              '_VARIADIC_MAX=10',  # for gtest/gmock on VC++ 2012
-            ],
-          }],
           # TODO(yukawa): Get rid of the following workaround when C++11 is
           # enabled on all the platforms.
           ['target_platform!="Windows"', {
diff --git a/src/win32/installer/installer.gyp b/src/win32/installer/installer.gyp
index f378707..8276191 100644
--- a/src/win32/installer/installer.gyp
+++ b/src/win32/installer/installer.gyp
@@ -72,18 +72,6 @@
           'mozc_zinnia_model_data_path': '',
           'mozc_tool_path': '',
           'conditions': [
-            ['use_dynamically_linked_qt==1 and compiler_target=="msvs" and compiler_target_version_int==1600', {
-              'debug_crt_merge_module_id_prefix': 'DebugCRT100',
-              'release_crt_merge_module_id_prefix': 'CRT100',
-              'debug_crt_merge_module_path': '<(merge_modules_dir)/Microsoft_VC100_DebugCRT_x86.msm',
-              'release_crt_merge_module_path': '<(merge_modules_dir)/Microsoft_VC100_CRT_x86.msm',
-            }],
-            ['use_dynamically_linked_qt==1 and compiler_target=="msvs" and compiler_target_version_int==1700', {
-              'debug_crt_merge_module_id_prefix': 'DebugCRT110',
-              'release_crt_merge_module_id_prefix': 'CRT110',
-              'debug_crt_merge_module_path': '<(merge_modules_dir)/Microsoft_VC110_DebugCRT_x86.msm',
-              'release_crt_merge_module_path': '<(merge_modules_dir)/Microsoft_VC110_CRT_x86.msm',
-            }],
             ['use_dynamically_linked_qt==1 and compiler_target=="msvs" and compiler_target_version_int==1800', {
               'debug_crt_merge_module_id_prefix': 'DebugCRT120',
               'release_crt_merge_module_id_prefix': 'CRT120',
diff --git a/src/win32/installer/installer_32bit.wxs b/src/win32/installer/installer_32bit.wxs
index 9d894d3..1b1384b 100644
--- a/src/win32/installer/installer_32bit.wxs
+++ b/src/win32/installer/installer_32bit.wxs
@@ -81,7 +81,7 @@
 
     <Package Keywords='Installer' Description='Google 日本語入力 インストーラー'
         Manufacturer='Google Inc.' Languages='1041' SummaryCodepage='932'
-        InstallerVersion='300' InstallPrivileges='elevated'
+        InstallerVersion='405' InstallPrivileges='elevated'
         Compressed='yes'/>
 
     <!-- Check if the user have the administrative privileges. -->
diff --git a/src/win32/installer/installer_64bit.wxs b/src/win32/installer/installer_64bit.wxs
index a5ba4ad..dd9c0bb 100644
--- a/src/win32/installer/installer_64bit.wxs
+++ b/src/win32/installer/installer_64bit.wxs
@@ -81,7 +81,7 @@
 
     <Package Keywords='Installer' Description='Google 日本語入力 インストーラー'
         Manufacturer='Google Inc.' Languages='1041' SummaryCodepage='932'
-        InstallerVersion='300' InstallPrivileges='elevated'
+        InstallerVersion='405' InstallPrivileges='elevated'
         Compressed='yes' Platform='x64' />
 
     <!-- Check if the user have the administrative privileges. -->
diff --git a/src/build_mozc.py b/src/build_mozc.py
index 3a69565..5b940d7 100644
--- a/src/build_mozc.py
+++ b/src/build_mozc.py
@@ -485,10 +485,10 @@
                       help='A path to the binary directory of wix.')
 
     # For internal Windows builds, gyp is expected to generate solution files
     # for Visual Studio 2010, which is a default compiler for Mozc.  However,
     # you can specify the target version explicitly via 'msvs_version' option
     # as follows.
-    parser.add_option('--msvs_version', dest='msvs_version', default='2010',
+    parser.add_option('--msvs_version', dest='msvs_version', default='2013',
                       help='Specifies the target MSVS version.')
 
   return parser.parse_args(args, values)
@@ -485,10 +485,10 @@
 
     # For internal Windows builds, gyp is expected to generate solution files
-    # for Visual Studio 2010, which is a default compiler for Mozc.  However,
+    # for Visual Studio 2013, which is a default compiler for Mozc.  However,
     # you can specify the target version explicitly via 'msvs_version' option
     # as follows.